summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.copr/Makefile2
-rw-r--r--.copr/prepare.sh4
-rw-r--r--Dockerfile8
-rw-r--r--Dockerfile.centos9
-rw-r--r--Dockerfile.fedora9
-rw-r--r--contrib/cirrus/lib.sh12
-rw-r--r--contrib/spec/podman.spec.in16
7 files changed, 28 insertions, 32 deletions
diff --git a/.copr/Makefile b/.copr/Makefile
index 05d9eb592..71142920b 100644
--- a/.copr/Makefile
+++ b/.copr/Makefile
@@ -16,4 +16,4 @@ build_binary:
clean:
rm -fr rpms
- rm -fr cri-o
+ rm -fr conmon
diff --git a/.copr/prepare.sh b/.copr/prepare.sh
index 1ad29da36..a40e2aadb 100644
--- a/.copr/prepare.sh
+++ b/.copr/prepare.sh
@@ -28,5 +28,5 @@ fi
mkdir build/
git archive --prefix "libpod-${COMMIT_SHORT}/" --format "tar.gz" HEAD -o "build/libpod-${COMMIT_SHORT}.tar.gz"
-git clone https://github.com/kubernetes-incubator/cri-o
-cd cri-o && git checkout 4cd5a7c60349be0678d9f1b0657683324c1a2726 && git archive --prefix "crio/" --format "tar.gz" HEAD -o "../build/crio.tar.gz"
+git clone https://github.com/containers/conmon
+cd conmon && git checkout f02c053eb37010fc76d1e2966de7f2cb9f969ef2 && git archive --prefix "conmon/" --format "tar.gz" HEAD -o "../build/conmon.tar.gz"
diff --git a/Dockerfile b/Dockerfile
index 2d1eedc90..f3afd5e25 100644
--- a/Dockerfile
+++ b/Dockerfile
@@ -56,13 +56,13 @@ RUN set -x \
&& rm -rf "$GOPATH"
# Install conmon
-ENV CRIO_COMMIT 7a283c391abb7bd25086a8ff91dbb36ebdd24466
+ENV CONMON_COMMIT f02c053eb37010fc76d1e2966de7f2cb9f969ef2
RUN set -x \
&& export GOPATH="$(mktemp -d)" \
- && git clone https://github.com/cri-o/cri-o.git "$GOPATH/src/github.com/cri-o/cri-o.git" \
- && cd "$GOPATH/src/github.com/cri-o/cri-o.git" \
+ && git clone https://github.com/containers/conmon.git "$GOPATH/src/github.com/containers/conmon.git" \
+ && cd "$GOPATH/src/github.com/containers/conmon.git" \
&& git fetch origin --tags \
- && git checkout -q "$CRIO_COMMIT" \
+ && git checkout -q "$CONMON_COMMIT" \
&& make \
&& install -D -m 755 bin/conmon /usr/libexec/podman/conmon \
&& rm -rf "$GOPATH"
diff --git a/Dockerfile.centos b/Dockerfile.centos
index 0a1d84bce..47f7182b6 100644
--- a/Dockerfile.centos
+++ b/Dockerfile.centos
@@ -64,15 +64,14 @@ RUN set -x \
&& install -D -m 755 "$GOPATH"/bin/easyjson /usr/bin/
# Install conmon
-ENV CRIO_COMMIT 7a283c391abb7bd25086a8ff91dbb36ebdd24466
+ENV CONMON_COMMIT f02c053eb37010fc76d1e2966de7f2cb9f969ef2
RUN set -x \
&& export GOPATH="$(mktemp -d)" \
- && git clone https://github.com/cri-o/cri-o.git "$GOPATH/src/github.com/cri-o/cri-o.git" \
- && cd "$GOPATH/src/github.com/cri-o/cri-o.git" \
+ && git clone https://github.com/containers/conmon.git "$GOPATH/src/github.com/containers/conmon.git" \
+ && cd "$GOPATH/src/github.com/containers/conmon.git" \
&& git fetch origin --tags \
- && git checkout -q "$CRIO_COMMIT" \
+ && git checkout -q "$CONMON_COMMIT" \
&& make \
- && make bin/conmon \
&& install -D -m 755 bin/conmon /usr/libexec/podman/conmon \
&& rm -rf "$GOPATH"
diff --git a/Dockerfile.fedora b/Dockerfile.fedora
index 6f0482c63..290fe3f82 100644
--- a/Dockerfile.fedora
+++ b/Dockerfile.fedora
@@ -68,15 +68,14 @@ RUN set -x \
&& install -D -m 755 "$GOPATH"/bin/easyjson /usr/bin/
# Install conmon
-ENV CRIO_COMMIT 7a283c391abb7bd25086a8ff91dbb36ebdd24466
+ENV CONMON_COMMIT f02c053eb37010fc76d1e2966de7f2cb9f969ef2
RUN set -x \
&& export GOPATH="$(mktemp -d)" \
- && git clone https://github.com/cri-o/cri-o.git "$GOPATH/src/github.com/cri-o/cri-o.git" \
- && cd "$GOPATH/src/github.com/cri-o/cri-o.git" \
+ && git clone https://github.com/containers/conmon.git "$GOPATH/src/github.com/containers/conmon.git" \
+ && cd "$GOPATH/src/github.com/containers/conmon.git" \
&& git fetch origin --tags \
- && git checkout -q "$CRIO_COMMIT" \
+ && git checkout -q "$CONMON_COMMIT" \
&& make \
- && make bin/conmon \
&& install -D -m 755 bin/conmon /usr/libexec/podman/conmon \
&& rm -rf "$GOPATH"
diff --git a/contrib/spec/podman.spec.in b/contrib/spec/podman.spec.in
index bb469d3b5..228f65b50 100644
--- a/contrib/spec/podman.spec.in
+++ b/contrib/spec/podman.spec.in
@@ -33,9 +33,9 @@
%global shortcommit0 %(c=%{commit0}; echo ${c:0:8})
# People want conmon packaged with the copr rpm
-%global import_path_conmon github.com/cri-o/cri-o
+%global import_path_conmon github.com/containers/conmon
%global git_conmon https://%{import_path_conmon}
-%global commit_conmon 4cd5a7c60349be0678d9f1b0657683324c1a2726
+%global commit_conmon f02c053eb37010fc76d1e2966de7f2cb9f969ef2
%global shortcommit_conmon %(c=%{commit_conmon}; echo ${c:0:7})
Name: podman
@@ -45,7 +45,7 @@ Summary: Manage Pods, Containers and Container Images
License: ASL 2.0
URL: %{git_podman}
Source0: %{git0}/archive/%{commit0}/%{repo}-%{shortcommit0}.tar.gz
-Source1: crio.tar.gz
+Source1: conmon.tar.gz
# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
#ExclusiveArch: %%{?go_arches:%%{go_arches}}%%{!?go_arches:%%{ix86} x86_64 aarch64 %%{arm}}
ExclusiveArch: aarch64 %{arm} ppc64le s390x x86_64
@@ -371,18 +371,16 @@ GOPATH=$GOPATH go generate ./cmd/podman/varlink/...
BUILDTAGS=$BUILDTAGS make binaries docs
# build conmon
-pushd crio
+pushd conmon
mkdir _output
pushd _output
-mkdir -p src/%{provider}.%{provider_tld}/{cri-o,opencontainers}
+mkdir -p src/%{provider}.%{provider_tld}/{containers,opencontainers}
ln -s $(dirs +1 -l) src/%{import_path_conmon}
popd
-ln -s vendor src
-export GOPATH=$(pwd)/_output:$(pwd):%{gopath}
export BUILDTAGS="selinux seccomp $(hack/btrfs_installed_tag.sh) $(hack/btrfs_tag.sh) containers_image_ostree_stub"
-BUILDTAGS=$BUILDTAGS make -C conmon
+BUILDTAGS=$BUILDTAGS make
popd
%install
@@ -402,7 +400,7 @@ install -p -m 644 %{repo}.conf %{buildroot}%{_datadir}/containers
# install conmon
install -dp %{buildroot}%{_libexecdir}/%{name}
-install -p -m 755 crio/bin/conmon %{buildroot}%{_libexecdir}/%{name}
+install -p -m 755 conmon/bin/conmon %{buildroot}%{_libexecdir}/%{name}
# source codes for building projects
%if 0%{?with_devel}
diff --git a/contrib/cirrus/lib.sh b/contrib/cirrus/lib.sh
index 667e24fd1..a285b133b 100644
--- a/contrib/cirrus/lib.sh
+++ b/contrib/cirrus/lib.sh
@@ -283,16 +283,16 @@ install_buildah() {
ooe.sh sudo make install
}
# Requires $GOPATH and $CRIO_COMMIT to be set
install_conmon(){
- echo "Installing conmon from commit $CRIO_COMMIT"
- req_env_var GOPATH CRIO_COMMIT
- DEST="$GOPATH/src/github.com/cri-o/cri-o.git"
+ echo "Installing conmon from commit $CONMON_COMMIT"
+ req_env_var GOPATH CONMON_COMMIT
+ DEST="$GOPATH/src/github.com/containers/conmon.git"
rm -rf "$DEST"
- ooe.sh git clone https://github.com/cri-o/cri-o.git "$DEST"
+ ooe.sh git clone https://github.com/containers/conmon.git "$DEST"
cd "$DEST"
ooe.sh git fetch origin --tags
- ooe.sh git checkout -q "$CRIO_COMMIT"
+ ooe.sh git checkout -q "$CONMON_COMMIT"
ooe.sh make
sudo install -D -m 755 bin/conmon /usr/libexec/podman/conmon
}
@@ -283,16 +283,16 @@ install_buildah() {
ooe.sh sudo make install
}
-# Requires $GOPATH and $CRIO_COMMIT to be set
+# Requires $GOPATH and $CONMON_COMMIT to be set
install_conmon(){